(developer.introduction)=
# Introduction
BEC Widgets is a framework providing modular components that can be integrated into various larger GUI applications. Each widget serves a specific purpose adhering to the single-responsibility principle as detailed in our [concepts section](developer.concepts), and offers a straightforward, user-friendly interface.
These widgets provide data visualisation tools and experimental control interfaces by triggering actions within BEC. 
If you're interested in contributing to BEC Widgets, please refer to our [contributing guide](developer.contributing), which provides instructions for setting up your development environment and creating your own widgets.

```{toctree}
---
maxdepth: 2
hidden: false
---

concepts/
contributing/
useful_links/
```